# gruvbox-sphinx
Sphinx HTML theme, forked from [autophagy/Insegel](https://github.com/autophagy/insegel), with modifications to the stylesheet for visual similarity to the [Gruvbox Vim theme](https://github.com/morhetz/gruvbox).

Code-block syntax highlighting was adapted from [daveyarwood/gruvbox-pygments](https://github.com/daveyarwood/gruvbox-pygments).

See Usage for installation and configuration instructions and Sample for a preview screenshot.

## Usage
Install with `pip`.
```bash
pip install gruvboxsphinx
```
Specify gruvbox-sphinx to be your project's HTML theme under the `conf.py` file.
```python
html_theme = "gruvboxsphinx"
```

## Sample
![Preview image](sample.png)
